pub fn parse_volume<D>(
block_cache: &mut BlockCache<D>,
lba_start: BlockIdx,
num_blocks: BlockCount,
) -> Result<VolumeType, Error<D::Error>>Expand description
Load the boot parameter block from the start of the given partition and determine if the partition contains a valid FAT16 or FAT32 file system.